@@ -13,6 +13,7 @@ use Type::Library
 
 use Const::Fast ();
 use List::Util 1.33 ();
+use Storable 3.06 (); # Regexp support
 use Type::Coercion;
 use Type::Tiny 1.002001;
 use Type::Utils -all;
@@ -24,7 +25,7 @@ use Types::TypeTiny ();
 
 use namespace::autoclean 0.28;
 
-our $VERSION = 'v0.3.3';
+our $VERSION = 'v0.3.7';
 
 
 sub VERSION { # for older Perls
@@ -125,7 +126,7 @@ Types::Const - Types that coerce references to read-only
 
 =head1 VERSION
 
-version v0.3.3
+version v0.3.7
 
 =head1 SYNOPSIS
 
@@ -146,7 +147,7 @@ version v0.3.3
 This is an I<experimental> type library that provides types that force
 read-only hash and array reference attributes to be deeply read-only.
 
-See the L<known issues|/KNOWN_ISSUES> below for a discussion of
+See the L<known issues|/"KNOWN ISSUES"> below for a discussion of
 side-effects.
 
 =head1 TYPES
@@ -165,6 +166,11 @@ This was added in v0.3.0.
 
 =for Pod::Coverage VERSION
 
+=head1 ROADMAP
+
+Support for Perl versions earlier than 5.10 will be removed sometime
+in 2019.
+
 =head1 SEE ALSO
 
 L<Const::Fast>
@@ -199,6 +205,11 @@ L<Devel::StrictMode> and only validate data structures during tests:
 Another means of improving performance is to only check the type
 once. (Since it is read-only, there is no need to re-check it.)
 
+=head2 RegexpRefs
+
+There may be an issue with regexp references. See
+L<RT#127635|https://rt.cpan.org/Ticket/Display.html?id=127635>.
+
 =head2 Bug reports and feature requests
 
 Please report any bugs or feature requests on the bugtracker website
@@ -217,6 +228,12 @@ and may be cloned from L<git://github.com/robrwo/Types-Const.git>
 
 Robert Rothenberg <rrwo@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
